import java.io.File;
import java.io.IOException;

import org.jdom.Document;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;

/**
 * Abstrakt superklass fr alla skklasser. 
 * 
 * @author billing
 * @author denniso
 */
public abstract class MapSearcher {
	
	/**
	 * Laddar en XML-fil och returnerar ett DOM-dokument. 
	 * Se http://www.jdom.org/ fr mer info. 
	 * @param srcFile XML-fil med kartan.
	 * @return DOM Document
	 * @throws IOException
	 * @throws JDOMException
	 * 
	 */
	public static Document loadXmlMap(File srcFile) throws IOException, JDOMException {
		SAXBuilder builder = new SAXBuilder();
		Document doc = builder.build(srcFile);
		return doc;
	}
	
	/**
	 * Specifiserar kartan. 
	 * 
	 * Denna metod anropas alltid fre skning och lagrar kartan som ett privat attribut. 
	 * Hur kartan representeras r upp till er att specificera.
	 * @param map XML-fil med kartan.
	 *  
	 */
	abstract public void setMap(File map);
	
	/**
	 * Utfr skning med bredden frst. 
	 * @param from Id fr startnod
	 * @param to Id fr mlnod
	 * @return Strng som representerar vgen frn start till ml. 
	 *  
	 */
	abstract public String breadthFirst(String from,String to);
	
	/**
	 * Utfr skning med djupet frst. 
	 * @param from Id fr startnod
	 * @param to Id fr mlnod
	 * @return Strng som representerar vgen frn start till ml. 
	 *  
	 */
	abstract public String depthFirst(String from,String to);
	
	/**
	 * Utfr skning med A*. 
	 * @param from Id fr startnod
	 * @param to Id fr mlnod
	 * @param fastest Anger om "snabbaste" eller (om falsk) kortaste vgen sks
	 * @return Strng som representerar vgen frn start till ml. 
	 *  
	 */
	abstract public String aStar(String from,String to,boolean fastest);
	
	/**
	 * Utfr skning med Greedy Search. 
	 * @param from Id fr startnod
	 * @param to Id fr mlnod
	 * @return Strng som representerar vgen frn start till ml. 
	 *  
	 */
	abstract public String greedySearch(String from,String to);
}
